(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     16136,        406]
NotebookOptionsPosition[     16081,        381]
NotebookOutlinePosition[     16584,        402]
CellTagsIndexPosition[     16541,        399]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Supplement to:",
  FontWeight->"Bold"],
 " Ice sheet mass loss caused by dust and black carbon accumulation by \
Goelles et al.\n",
 StyleBox["Correspondence:",
  FontWeight->"Bold"],
 " thomas.goelles@gmail.com"
}], "Text"],

Cell[CellGroupData[{

Cell["Melt-equivalent Temperature", "Chapter"],

Cell["\<\
How much higher must the temperature be in order to reach the same amount of \
melt as by adding impurities? 
The function is derived from the SMB model and the albedo reduction \
parametrisation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sol", "=", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Rho]", "w"], "*", 
           SubscriptBox["L", "m"]}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.46", "+", 
             RowBox[{"0.00006", "h"}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Alpha]"}], ")"}], "*", 
           SubscriptBox["S", "TOA"]}], "-", "c", "+", 
          RowBox[{"\[Lambda]", "*", 
           RowBox[{"(", 
            RowBox[{"T", "+", "\[CapitalDelta]T"}], ")"}]}]}], ")"}]}], "==", 
       
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Rho]", "w"], "*", 
           SubscriptBox["L", "m"]}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.46", "+", 
             RowBox[{"0.00006", "h"}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"(", 
              RowBox[{"\[Alpha]", "+", "\[CapitalDelta]\[Alpha]"}], ")"}]}], 
            ")"}], "*", 
           SubscriptBox["S", "TOA"]}], "-", "c", "+", 
          RowBox[{"\[Lambda]", "*", 
           RowBox[{"(", "T", ")"}]}]}], ")"}]}]}], ",", "\[CapitalDelta]T"}], 
     "]"}]}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[CapitalDelta]T", "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["L", "m"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"1.`", " ", "c"}], 
         RowBox[{
          SubscriptBox["L", "m"], " ", 
          SubscriptBox["\[Rho]", "w"]}]], "-", 
        FractionBox[
         RowBox[{"T", " ", "\[Lambda]"}], 
         RowBox[{
          SubscriptBox["L", "m"], " ", 
          SubscriptBox["\[Rho]", "w"]}]], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"0.46`", "\[VeryThinSpace]", "+", 
            RowBox[{"0.00006`", " ", "h"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1.`", "\[VeryThinSpace]", "-", 
            RowBox[{"1.`", " ", "\[Alpha]"}]}], ")"}], " ", 
          SubscriptBox["S", "TOA"]}], 
         RowBox[{
          SubscriptBox["L", "m"], " ", 
          SubscriptBox["\[Rho]", "w"]}]], "+", 
        FractionBox[
         RowBox[{"1.`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "1.`"}], " ", "c"}], "+", 
            RowBox[{"T", " ", "\[Lambda]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.46`", "\[VeryThinSpace]", "+", 
               RowBox[{"0.00006`", " ", "h"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"1.`", "\[VeryThinSpace]", "-", 
               RowBox[{"1.`", " ", "\[Alpha]"}], "-", 
               RowBox[{"1.`", " ", "\[CapitalDelta]\[Alpha]"}]}], ")"}], " ", 
             
             SubscriptBox["S", "TOA"]}]}], ")"}]}], 
         RowBox[{
          SubscriptBox["L", "m"], " ", 
          SubscriptBox["\[Rho]", "w"]}]]}], ")"}], " ", 
      SubscriptBox["\[Rho]", "w"]}], "\[Lambda]"]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["and simplified", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"\[CapitalDelta]T", "/.", "sol"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"0.`", "\[VeryThinSpace]", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.46`"}], "-", 
       RowBox[{"0.00006`", " ", "h"}]}], ")"}], " ", 
     "\[CapitalDelta]\[Alpha]", " ", 
     SubscriptBox["S", "TOA"]}]}], "\[Lambda]"], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The plot shows how much temperature change is needed in order to achieve the \
same amount of melt as an additional black carbon concentration. The \
temperature value depends on the \[OpenCurlyDoubleQuote]baseline BC \
concentration\[CloseCurlyDoubleQuote], i.e. the initial BC concentration of \
the ice.\
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`baseline$$ = 
    0.027200000000000002`, $CellContext`bcconc$$ = 
    0.026153846153846153`, $CellContext`h$$ = 500, $CellContext`lambda$$ = 
    10, $CellContext`pr$$ = 0.1, $CellContext`pry$$ = 4, $CellContext`SSA$$ = 
    2, $CellContext`STOA$$ = 300, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`h$$], 500, "Elevation [m]"}, 0, 3000}, {{
       Hold[$CellContext`STOA$$], 300, 
       "Insolation TOA [W \!\(\*SuperscriptBox[\(m\), \(-2\)]\)]"}, 0, 500}, {{
       Hold[$CellContext`SSA$$], 2, 
       "Specific surface area [\!\(\*SuperscriptBox[\(cm\), \(2\)]\) \
\!\(\*SuperscriptBox[\(g\), \(-1\)]\)]"}, 1, 10}, {{
       Hold[$CellContext`lambda$$], 10, 
       "Long-wave radiation coefficient \[Lambda] [W \!\(\*SuperscriptBox[\(m\
\), \(-2\)]\) \!\(\*SuperscriptBox[\(K\), \(-1\)]\)]"}, 8, 12}, {{
       Hold[$CellContext`baseline$$], 0, "Baseline BC concentration [ppm]"}, 
      0, 
      Dynamic[$CellContext`pr$$]}, {{
       Hold[$CellContext`bcconc$$], 
       Rational[3, 100], "BC concentration"}, {
      Rational[1, 10000] -> "dust Holocene, in BC equivalent conc.", 0.001 -> 
       "BC pre-industrial", 0.003 -> "BC industrial mean", 
       0.004131868131868132 -> 
       "Dust 18.8 [g \!\(\*SuperscriptBox[\(m\), \(-2\)]\)] in BC equivalent \
conc.", Rational[1, 100] -> 
       "Dust 2000 [ng \!\(\*SuperscriptBox[\(g\), \(-1\)]\)] in BC equivalent \
conc.", 0.026153846153846153` -> 
       "Dust 119 [g \!\(\*SuperscriptBox[\(m\), \(-2\)]\)] in BC equivalent \
conc.", Rational[3, 100] -> 
       "Dust 6000 [ng \!\(\*SuperscriptBox[\(g\), \(-1\)]\)] in BC equivalent \
conc."}}, {{
       Hold[$CellContext`pr$$], 0.1, "x range of plot in ppm"}, {0.1, 2.}}, {{
      
       Hold[$CellContext`pry$$], 4, "y range of plot in K"}, {4, 10}}}, 
    Typeset`size$$ = {469., {99., 103.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`h$27614$$ = 0, $CellContext`STOA$27615$$ = 
    0, $CellContext`SSA$27616$$ = 0, $CellContext`lambda$27617$$ = 
    0, $CellContext`baseline$27618$$ = 0, $CellContext`bcconc$27619$$ = 
    False, $CellContext`pr$27620$$ = False, $CellContext`pry$27621$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`baseline$$ = 0, $CellContext`bcconc$$ = 
        Rational[3, 100], $CellContext`h$$ = 500, $CellContext`lambda$$ = 
        10, $CellContext`pr$$ = 0.1, $CellContext`pry$$ = 
        4, $CellContext`SSA$$ = 2, $CellContext`STOA$$ = 300}, 
      "ControllerVariables" :> {
        Hold[$CellContext`h$$, $CellContext`h$27614$$, 0], 
        Hold[$CellContext`STOA$$, $CellContext`STOA$27615$$, 0], 
        Hold[$CellContext`SSA$$, $CellContext`SSA$27616$$, 0], 
        Hold[$CellContext`lambda$$, $CellContext`lambda$27617$$, 0], 
        Hold[$CellContext`baseline$$, $CellContext`baseline$27618$$, 0], 
        Hold[$CellContext`bcconc$$, $CellContext`bcconc$27619$$, False], 
        Hold[$CellContext`pr$$, $CellContext`pr$27620$$, False], 
        Hold[$CellContext`pry$$, $CellContext`pry$27621$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[{
         Plot[
          $CellContext`func2[$CellContext`h$$, $CellContext`STOA$$, \
$CellContext`lambda$$, $CellContext`SSA$$, \
$CellContext`albedoeffectiveBCconc], {$CellContext`albedoeffectiveBCconc, 
           0, $CellContext`pr$$}, 
          FrameLabel -> {"BC concentration [ppm]", "Temperature change [K]"}, 
          PlotTheme -> "Monochrome", Frame -> True, PlotLegends -> 
          "Expressions", PlotRange -> {0, $CellContext`pry$$}, 
          
          GridLines -> {{$CellContext`baseline$$, $CellContext`baseline$$ + \
$CellContext`bcconc$$}, None}, ImageSize -> 300], 
         Panel[
          Column[{"Temperature change equivalent", 
            
            Round[$CellContext`func2[$CellContext`h$$, $CellContext`STOA$$, \
$CellContext`lambda$$, $CellContext`SSA$$, $CellContext`baseline$$ + \
$CellContext`bcconc$$] - $CellContext`func2[$CellContext`h$$, \
$CellContext`STOA$$, $CellContext`lambda$$, $CellContext`SSA$$, \
$CellContext`baseline$$], 0.01]}]]}], 
      "Specifications" :> {{{$CellContext`h$$, 500, "Elevation [m]"}, 0, 3000,
          Appearance -> 
         "Labeled"}, {{$CellContext`STOA$$, 300, 
          "Insolation TOA [W \!\(\*SuperscriptBox[\(m\), \(-2\)]\)]"}, 0, 500,
          Appearance -> 
         "Labeled"}, {{$CellContext`SSA$$, 2, 
          "Specific surface area [\!\(\*SuperscriptBox[\(cm\), \(2\)]\) \
\!\(\*SuperscriptBox[\(g\), \(-1\)]\)]"}, 1, 10, Appearance -> 
         "Labeled"}, {{$CellContext`lambda$$, 10, 
          "Long-wave radiation coefficient \[Lambda] [W \!\(\*SuperscriptBox[\
\(m\), \(-2\)]\) \!\(\*SuperscriptBox[\(K\), \(-1\)]\)]"}, 8, 12, Appearance -> 
         "Labeled"}, {{$CellContext`baseline$$, 0, 
          "Baseline BC concentration [ppm]"}, 0, 
         Dynamic[$CellContext`pr$$], Appearance -> 
         "Labeled"}, {{$CellContext`bcconc$$, 
          Rational[3, 100], "BC concentration"}, {
         Rational[1, 10000] -> "dust Holocene, in BC equivalent conc.", 0.001 -> 
          "BC pre-industrial", 0.003 -> "BC industrial mean", 
          0.004131868131868132 -> 
          "Dust 18.8 [g \!\(\*SuperscriptBox[\(m\), \(-2\)]\)] in BC \
equivalent conc.", Rational[1, 100] -> 
          "Dust 2000 [ng \!\(\*SuperscriptBox[\(g\), \(-1\)]\)] in BC \
equivalent conc.", 0.026153846153846153` -> 
          "Dust 119 [g \!\(\*SuperscriptBox[\(m\), \(-2\)]\)] in BC \
equivalent conc.", Rational[3, 100] -> 
          "Dust 6000 [ng \!\(\*SuperscriptBox[\(g\), \(-1\)]\)] in BC \
equivalent conc."}}, {{$CellContext`pr$$, 0.1, "x range of plot in ppm"}, {
         0.1, 2.}}, {{$CellContext`pry$$, 4, "y range of plot in K"}, {4, 
         10}}}, "Options" :> {AutorunSequencing -> {All, 10}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1026., {127., 132.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`func2[
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`STOA, 
          Blank[]], 
         Pattern[$CellContext`lambda, 
          Blank[]], 
         Pattern[$CellContext`SSA, 
          Blank[]], 
         Pattern[$CellContext`albedoeffectiveBCconc, 
          Blank[]]] := (
         0. + (System2D`dalbedoGSBC[$CellContext`SSA, \
$CellContext`albedoeffectiveBCconc] (-0.46 - 
            0.00006 $CellContext`h)) $CellContext`STOA)/$CellContext`lambda, \
$CellContext`SSA$$ = 2, System2D`dalbedoGSBC[
         Pattern[System2D`Private`SSAInsqcmperg, 
          Blank[]], 
         Pattern[System2D`Private`bcINppm, 
          Blank[]]] := 
       Max[{0.04 - (1.48 - 
          System2D`Private`SSAInsqcmperg^(-0.07)), -(
           System2D`Private`bcINppm^0.55/(0.16 + 
           0.6 System2D`Private`SSAInsqcmperg^0.5 + (1.8 
             System2D`Private`bcINppm^0.6)/
            System2D`Private`SSAInsqcmperg^0.25))}], 
       TagSet[System2D`dalbedoGSBC, 
        MessageName[System2D`dalbedoGSBC, "usage"], ""]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Input"],

Cell[CellGroupData[{

Cell["References", "Subsection"],

Cell["\<\
SMB model: Robinson, A., Calov, R. and Ganopolski, A.: An efficient regional \
energy-moisture balance model for simulation of the Greenland Ice Sheet \
response to climate change, The Cryosphere, 4(2), 129\[Dash]144, \
doi:10.5194/tc-4-129-2010, 2010.

Darkening due to BC: Gardner, A. and Sharp, M.: A review of snow and ice \
albedo and the development of a new physically based broadband albedo \
parameterization, Journal of Geophysical Research, 115(F1), F01009, \
doi:10.1029/2009JF001444, 2010.

BC values: McConnell, J., Edwards, R., Kok, G., Flanner, M., Zender, C. S., \
Saltzman, E., Banta, J., Pasteris, D., Carter, M. and Kahl, J.: 20th-century \
industrial black carbon emissions altered arctic climate forcing, Science, \
317(5843), 1381, doi:10.1126/science.1144856, 2007.

Dust values: Ruth, U.: Dust concentration in the NGRIP ice core, \
doi:10.1594/PANGAEA.587836, Supple-
ment to: Ruth, U., Bigler, M., R\[ODoubleDot]thlisberger, R., \
Siggaard-Andersen, M.-L., Kipfstuhl, J., Goto- Azuma, K., Hansson, M. E., \
Johnsen, S. J., Lu, H., and Steffensen, J. P.: Ice core evidence for a very \
tight link between North Atlantic and east Asian glacial climate, Geophys. \
Res. Lett., 34, L03706, doi:10.1029/2006GL027876, 2007.

Takeuchi, N., Nagatsuka, N., Uetake, J. and Shimada, R.: Spatial variations \
in impurities (cryoconite) on glaciers in northwest Greenland, Bulletin of \
Glacier Research, 32(0), 85\[Dash]94, doi:10.5331/bgr.32.85, 2014.

Convertion to concentration: Goelles, T. and B\[OSlash]ggild, C. E.: Albedo \
reduction caused by black carbon and dust accumulation: a quantitive model \
applied to the western margin of the Greenland ice sheet, The Cryosphere \
Discuss., 9(1), 1345\[Dash]1381, doi:10.5194/tcd-9-1345-2015, 2015.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1310, 822},
WindowMargins->{{Automatic, 207}, {65, Automatic}},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 9, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[1464, 33, 251, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[1740, 45, 46, 0, 65, "Chapter"],
Cell[1789, 47, 220, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[2034, 56, 1541, 46, 63, "Input"],
Cell[3578, 104, 1845, 51, 63, "Output"]
}, Open  ]],
Cell[5438, 158, 30, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[5493, 162, 102, 2, 28, "Input"],
Cell[5598, 166, 330, 10, 47, "Output"]
}, Open  ]],
Cell[5943, 179, 330, 6, 49, "Text"],
Cell[6276, 187, 7927, 152, 276, "Input"],
Cell[CellGroupData[{
Cell[14228, 343, 32, 0, 44, "Subsection"],
Cell[14263, 345, 1790, 32, 353, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature jwDEo38AFsem2Bg1VsKIMpkt *)
